@@ -22,9 +22,9 @@ from .cfl import CFL
 
 import plot
 
-__all__.extend(['ClawSolver1D','ClawSolver2D','ClawSolver3D','SharpClawSolver1D','SharpClawSolver2D'])
+__all__.extend(['ClawSolver1D','ClawSolver2D','ClawSolver3D','SharpClawSolver1D','SharpClawSolver2D','SharpClawSolver3D'])
 from .classic.solver import ClawSolver1D, ClawSolver2D, ClawSolver3D
-from .sharpclaw.solver import SharpClawSolver1D, SharpClawSolver2D
+from .sharpclaw.solver import SharpClawSolver1D, SharpClawSolver2D,SharpClawSolver2D,SharpClawSolver3D
 
 
 # Sub-packages
