@@ -5,6 +5,8 @@ def configuration(parent_package='', top_path=None):
     from numpy.distutils.misc_util import Configuration
 
     config = Configuration('visclaw', parent_package, top_path)
+    config.add_subpackage('JSAnimation')
+    config.add_data_dir('JSAnimation/icons')
     return config
 
 
